Learn R Programming

ehymet (version 0.1.1)

MEI: Modified Epigraph Index (MEI) for functional dataset.

Description

The Modified Epigraph Index of a curve x is one minus the proportion of "time" the curves in the sample are above x.

Usage

MEI(curves, ...)

Value

numeric vector containing the MEI for each curve.

Arguments

curves

matrix where each row represents a curve, and each column represents values along the curve or an array with dimension \(n \times p \times q\) with \(n\) curves, \(p\) values along the curve, and \(q\) dimensions.

...

Ignored.

Examples

Run this code
x <- matrix(c(1, 2, 3, 3, 2, 1, 5, 2, 3, 9, 8, 7), ncol = 3, nrow = 4)
MEI(x)
y <- array(c(1, 2, 3, 3, 2, 1, 5, 2, 3, 9, 8, 7, -1, -5, -6, 2, 3, 0, -1, 0, 2, -1, -2, 0),
  dim = c(3, 4, 2)
)
MEI(y)

Run the code above in your browser using DataLab