Learn R Programming

ehymet (version 0.1.1)

MHI: Modified Hypograph Index (MHI) for a functional dataset

Description

The Modified Hypograph Index of a curve x is the proportion of "time" the curves in the sample are below x.

Usage

MHI(curves, ...)

Value

numeric vector containing the MHI for each curve.

Arguments

curves

matrix where each row represents a curve, and each column represents values along the curve or an array with dimension \(n \times p \times q\) with \(n\) curves, \(p\) values along the curve, and \(q\) dimensions.

...

Ignored.

Examples

Run this code
x <- matrix(c(1, 2, 3, 3, 2, 1, 5, 2, 3, 9, 8, 7), ncol = 3, nrow = 4)
MHI(x)
y <- array(c(1, 2, 3, 3, 2, 1, 5, 2, 3, 9, 8, 7, -1, -5, -6, 2, 3, 0, -1, 0, 2, -1, -2, 0),
  dim = c(3, 4, 2)
)
MHI(y)

Run the code above in your browser using DataLab