The Epigraph Index of a curve x is one minus the proportion of curves
in the sample that are above x.
Usage
EI(curves, ...)
Value
numeric vector containing the EI for each curve.
Arguments
curves
matrix where each row represents a curve, and each column
represents values along the curve or array with dimension
\(n \times p \times q\) with \(n\) curves, \(p\) values along the curve, and
\(q\) dimensions.