The Hypograph Index of a curve x is the proportion of curves in the sample
that are below x.
Usage
HI(curves, ...)
Value
numeric vector containing the HI for each curve.
Arguments
curves
matrix where each row represents a curve, and each column
represents values along the curve or array with dimension
\(n \times p \times q\) with \(n\) curves, \(p\) values along the curve, and
\(q\) dimensions.