MEI: Modified Epigraph Index (MEI) for functional dataset.
Description
The Modified Epigraph Index of a curve x is one minus the proportion of
"time" the curves in the sample are above x.
Usage
MEI(curves, ...)
Value
numeric vector containing the MEI for each curve.
Arguments
curves
matrix where each row represents a curve, and each column
represents values along the curve or an array with dimension
\(n \times p \times q\) with \(n\) curves, \(p\) values along the curve, and
\(q\) dimensions.