MHI: Modified Hypograph Index (MHI) for a functional dataset
Description
The Modified Hypograph Index of a curve x is the proportion of "time"
the curves in the sample are below x.
Usage
MHI(curves, ...)
Value
numeric vector containing the MHI for each curve.
Arguments
curves
matrix where each row represents a curve, and each column
represents values along the curve or an array with dimension
\(n \times p \times q\) with \(n\) curves, \(p\) values along the curve, and
\(q\) dimensions.