A list containing hierarchical clustering results
for each configuration
A list containing kmeans clustering results for each configuration
Arguments
ind_data
Dataframe containing indices applied to the original data and
its first and second derivatives. See generate_indices.
vars_combinations
list containing one or more combinations of indices in
ind_data. If it is non-named, the names of the variables are set to
vars1, ..., varsk, where k is the number of elements in vars_combinations.
dist_vector
Atomic vector of distance metrics. The possible values are,
"euclidean", "mahalanobis" or both.
n_cluster
Number of clusters to create.
init
Centroids initialization meathod. It can be "random" or "kmeanspp".
true_labels
Vector of true labels for validation.
(if it is not known true_labels is set to NULL)
n_cores
Number of cores to do parallel computation. 1 by default,
which mean no parallel execution.